//
//  NSDate+NSDateHelper.h
//  ePoise Job Interviews
//
//  Created by Amit Singh on 24/07/15.
//  Copyright (c) 2015 ePoise Systems. All rights reserved.

#import <Foundation/Foundation.h>

/**
    Helper class of NSDate with convenience methods for returning the date as a string. The class uses date formatting patterns from http://www.unicode.org/reports/tr35/tr35-31/tr35-dates.html#Date_Format_Patterns
 */
@interface NSDate(Helper)

/**
 Creates and returns an NSDate object with the year, month and day. The time is set to 00:00 in the time zone UTC. The Gregorian calendar is used.
 @param year  The year of the date.
 @param month The month of the date.
 @param day   The day of the date.
 @return      The NSDate.
 */
+ (NSDate *)dateFromYear:(NSInteger)year Month:(NSInteger)month Day:(NSInteger)day;

/**
 Creates and returns an NSDate object with the year, month and day. The time is set to 00:00 in the local time zone. The Gregorian calendar is used.
 @param year  The year of the date.
 @param month The month of the date.
 @param day   The day of the date.
 @return      The NSDate.
 */
+ (NSDate *)dateInLocalTimeZoneFromYear:(NSInteger)year Month:(NSInteger)month Day:(NSInteger)day;

/**
 Creates and returns an NSDate object from a string in the MM-dd-YYYY format.
 @param dateString The date string.
 @return The string converted to date.
 */
+ (NSDate *)dateFromStringInMMddYYYYFormat:(NSString *)dateString;

/**
 Creates and returns an NSDate object from a string in the d MMM YYYY format.
 @param dateString The date string.
 @return The string converted to date.
 */
+ (NSDate *)dateFromStringIndMMMYYYYFormat:(NSString *)dateString;

/**
 Creates and returns an NSDate object from a string in the d MMM YYYY format.
 @param dateString The date string.
 @return The string converted to date.
 */

+ (NSDate *)dateFromStringInyyyyMMddHHmmssSSSFormat:(NSString *)dateString;

/**
 Creates and returns an NSDate object from a string in the yyyy-MM-dd'T'HH:mm:ss format.
 @param dateString The date string.
 @return The string converted to date.
 */

+ (NSDate *)dateFromStringInYYYYMMDDHHMMSSFormat:(NSString *)dateString;

/*
 Accepts a string like "08-24-2014 11:30:00"
 Returns the date formatted in MM-DD-YYYY 11:30:00 +0000
 */

/**
    Compares the date with the receiver for equality of year, month and day, ignoring the timezone, hour, minute and second. And for those finicky kinds, yes, it also ignores era.
    @param date The date to compare with.
    @return YES if the dates fall on the same day, no otherwise.
 */
- (BOOL)isSameDayAsDate:(NSDate *)date;

/**
 Returns a string representation of a given date formatted as "yyyy-MM-dd HH:mm:ss.SSS" using the receiver’s current settings.
 @return A string representation of date formatted as "yyyy-MM-dd HH:mm:ss.SSS" using the receiver’s current settings.
 */
- (NSString *)formattedAsyyyyMMddHHmmssSSS;

/**
    Returns a string representation of a given date formatted as "MM/dd/YYYY h:mm a" using the receiver’s current settings.
    @return A string representation of date formatted as "MM/dd/YYYY h:mm a" using the receiver’s current settings.
 */
- (NSString *)formattedAsMMDDYYYYhMMa;


/**
 Returns a string representation of a given date formatted as "d-M-YYYY" using the receiver’s current settings.
 @return A string representation of date formatted as "d-M-YYYY" using the receiver’s current settings.
 */
- (NSString *)formattedAsddMMYYYY;

/**
 Returns a string representation of a given date formatted as "d/M/YYYY" using the receiver’s current settings.
 @return A string representation of date formatted as "d/M/YYYY" using the receiver’s current settings.
 */
- (NSString *)formattedAsddMMYYYYWithSlashSeprator;

/**
 Returns a string representation of a given date formatted as MMM d, YYYY (example: Jul 3, 1971).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsMMMdYYYY;


/**
 Returns a string representation of a given date formatted as MMMM d, YYYY (example: July 3, 1971).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsMMMMdYYYY;

/**
 Returns a string representation of a given date formatted as YYYY-MM-dd (example: 1989-09-24).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsYYYYMMdd;

/**
    Returns a string representation of a given date formatted as MMMM d YYYY (example: July 3 1971).
    @return The formatted string representation of the receiver.
 */
// - (NSString *)formattedAsMMMMdYYYYWithoutComma;


/**
 Returns a string representation of a given date formatted as d MMM YYYY (example: 3 Jul 1971).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsdMMMYYYY;


/**
 Returns a string representation of a given date formatted as d MMMM YYYY (example: 3 July 1971).
 @return The formatted string representation of the receiver.
*/
- (NSString *)formattedAsdMMMMYYYY;


/**
 Returns a string representation of a given date formatted as M/d/YY (example: 7/3/71).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsMdYY;


/**
 Returns a string representation of a given date formatted as M/d/YYYY (example: 7/3/1971).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsMdYYYY;


/**
 Returns a string representation of a given date formatted as MM/dd/YY (example: 07/03/71).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsMMddYY;

/**
 Returns a string representation of a given date formatted as MM/dd/YYYY (example: 07/03/1971).
 @return The formatted string representation of the receiver.
 */
- (NSString *)formattedAsMMddYYYY;


/*
 Formatted As Time Ago
 Returns the date formatted as Time Ago (in the style of the mobile time ago date formatting for Facebook)
 */
- (NSString *)formattedAsTimeAgo;


/*
 Formatted As Time Ago
 Returns the date formatted as Time Ago (in the style of the mobile time ago date formatting for Facebook)
 */
- (NSString *)formattedAsWeekMonthDay;


/*
 returns the date formatted in eee
 */
- (NSString *)formattedAsWeek;

@end
